@@ -6,6 +6,11 @@ use Exporter::Auto;
 
 sub DataTable {
     load Dash::Table::DataTable;
+    if ( Dash::Table::DataTable->can("children") ) {
+        if ( ( ( scalar @_ ) % 2 ) ) {
+            unshift @_, "children";
+        }
+    }
     return Dash::Table::DataTable->new(@_);
 }
 1;
@@ -22,7 +27,7 @@ Dash::TableFunctions
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 AUTHOR
 
